← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~cjohnston/launchpad/812225 into lp:launchpad

 

Chris Johnston has proposed merging lp:~cjohnston/launchpad/812225 into lp:launchpad.

Commit message:
Add package as an 'also affects' on bug reports

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)
Related bugs:
  Bug #812225 in Launchpad itself: ""Also affects distribution" should read "Also affects distribution/package""
  https://bugs.launchpad.net/launchpad/+bug/812225

For more details, see:
https://code.launchpad.net/~cjohnston/launchpad/812225/+merge/214306
-- 
https://code.launchpad.net/~cjohnston/launchpad/812225/+merge/214306
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~cjohnston/launchpad/812225 into lp:launchpad.
=== modified file 'lib/lp/bugs/browser/bug.py'
--- lib/lp/bugs/stories/bug-also-affects/xx-request-distribution-no-release-fix.txt	2009-06-12 16:36:02 +0000
+++ lib/lp/bugs/stories/bug-also-affects/xx-request-distribution-no-release-fix.txt	2014-04-04 16:30:28 +0000
@@ -16,7 +16,7 @@
 Any user can request a fix for it.
 
     >>> user_browser.open('http://launchpad.dev/bugs/4')
-    >>> user_browser.getLink('Also affects distribution').click()
+    >>> user_browser.getLink('Also affects distribution/package').click()
     >>> user_browser.getControl('Distribution').value = ['gentoo']
     >>> user_browser.getControl('Continue').click()
     >>> user_browser.url
@@ -36,7 +36,7 @@
     False
 
     >>> user_browser.open('http://launchpad.dev/bugs/7')
-    >>> user_browser.getLink('Also affects distribution').click()
+    >>> user_browser.getLink('Also affects distribution/package').click()
     >>> user_browser.getControl('Distribution').value = ['gentoo']
     >>> user_browser.getControl('Source Package').value = ''
     >>> user_browser.getControl('URL').value = (

=== modified file 'lib/lp/bugs/stories/bugs/xx-edit-no-currentrelease-distribution-task.txt'
--- lib/lp/bugs/stories/bugs/xx-edit-no-currentrelease-distribution-task.txt	2009-06-12 16:36:02 +0000
+++ lib/lp/bugs/stories/bugs/xx-edit-no-currentrelease-distribution-task.txt	2014-04-04 16:30:28 +0000
@@ -5,7 +5,7 @@
 tasks currently open, so let's add one.
 
     >>> user_browser.open('http://launchpad.dev/bugs/4')
-    >>> user_browser.getLink('Also affects distribution').click()
+    >>> user_browser.getLink('Also affects distribution/package').click()
 
     >>> user_browser.getControl('Distribution').value = ['gentoo']
     >>> user_browser.getControl('Continue').click()


Follow ups
--- lib/lp/bugs/browser/bug.py	2014-02-26 04:41:31 +0000
+++ lib/lp/bugs/browser/bug.py	2014-04-04 16:30:28 +0000
@@ -260,8 +260,8 @@
         return Link('+choose-affected-product', text, icon='add')
 
     def adddistro(self):
-        """Return the 'Also affects distribution' Link."""
-        text = 'Also affects distribution'
+        """Return the 'Also affects distribution/package' Link."""
+        text = 'Also affects distribution/package'
         return Link('+distrotask', text, icon='add')
 
     def subscription(self):

=== modified file 'lib/lp/bugs/stories/bug-also-affects/xx-request-distribution-no-release-fix.txt'